@@ -45,34 +45,32 @@
    return(ts(yhat))
  }
 
-# Compute impulse responses using vec(ar.coefs | exog coefs).  This is
-# a utility function, since it speeds computation of the VAR IRFs in
-# Monte Carlo simulations where the vec(coefs) is drawn.
-"irf.var.from.beta" <-
-function(A0,bvec,nsteps)
-  { m <- ncol(A0)
-    p <- (length(bvec))/m^2;
-    bmtx <- matrix(bvec,ncol=m)
-    ar.coefs<-t(bmtx)     # extract the ar coefficients
-    dim(ar.coefs)<-c(m,m,p)              # push ar coefs into M x M x P array
-    ar.coefs<-aperm(ar.coefs,c(2,1,3))   # reorder array so columns
-                                         # are for eqn
+## # Compute impulse responses using vec(ar.coefs | exog coefs).  This is
+## # a utility function, since it speeds computation of the VAR IRFs in
+## # Monte Carlo simulations where the vec(coefs) is drawn.
+## "irf.var.from.beta" <-
+## function(A0,bvec,nsteps)
+## {   m <- ncol(A0)
+##     p <- (length(bvec))/m^2;
+##     bmtx <- matrix(bvec,ncol=m)
+##     ar.coefs<-t(bmtx)     # extract the ar coefficients
+##     dim(ar.coefs)<-c(m,m,p)              # push ar coefs into M x M x P array
+##     ar.coefs<-aperm(ar.coefs,c(2,1,3))   # reorder array so columns
+##                                          # are for eqn
+##     impulses <- irf.VAR(list(ar.coefs=ar.coefs),nsteps,A0=A0)$mhat
+##     impulses <- aperm(impulses, c(3,1,2)) # flips around the responses
+##                                           # to stack them as series
+##                                           # for each response, so the
+##                                           # first nstep elements are
+##                                           # the responses to the first
+##                                           # shock, the second are the
+##                                           # responses of the first
+##                                           # variable to the next
+##                                           # shock, etc.
 
-    impulses <- irf.VAR(list(ar.coefs=ar.coefs),nsteps,A0=A0)$mhat
-    impulses <- aperm(impulses, c(3,1,2)) # flips around the responses
-                                          # to stack them as series
-                                          # for each response, so the
-                                          # first nstep elements are
-                                          # the responses to the first
-                                          # shock, the second are the
-                                          # responses of the first
-                                          # variable to the next
-                                          # shock, etc.
-
-    dim(impulses)<-c((m^2)*nsteps,1)
-
-    return(impulses)
-  }
+##     dim(impulses)<-c((m^2)*nsteps,1)
+##     return(impulses)
+##   }
 
 # posterior fit measures for szbvar
 "posterior.fit.szbvar" <-
@@ -249,11 +247,11 @@ function(capT,m,ncoef,num.exog,nu,H0,S0,Y,X,hstar1,Sh,u, Bh,Sh1)
 # Functions to "flatten" or conserve A0 storage and rebuild the
 # A0 matrices from the "flat" objects
 
-"A0.flatten" <- function(A0){
-    struct <- which(A0 != 0)
-    A0.flat <- as.vector(A0)[struct]
-    return(A0.flat)
-}
+## "A0.flatten" <- function(A0){
+##     struct <- which(A0 != 0)
+##     A0.flat <- as.vector(A0)[struct]
+##     return(A0.flat)
+## }
 
 "A0.get" <- function(A0,index){
     if(index==1) {st <- 1} else {st <- 1 + (index-1)*length(A0$struct)}
@@ -265,56 +263,56 @@ function(capT,m,ncoef,num.exog,nu,H0,S0,Y,X,hstar1,Sh,u, Bh,Sh1)
 # Functions to "flatten" or conserve W storage and rebuild the W
 # matrices from the "flat" objects
 
-"W.flatten" <- function(W){
-    m <- length(W)
-    W.flat <- vector(mode="numeric", length=((m-1)*(m-1)*m))
-    W.index <- vector(mode="numeric", length=m)
-    W.index[1] <- dim(W[[1]])[1]*dim(W[[1]])[2]
-    W.flat[1:W.index[1]] <- as.vector(W[[1]])
-    for(i in 2:m){
-      W.index[i] <- dim(W[[i]])[1]*dim(W[[i]])[2] + W.index[i-1]
-      W.flat[(W.index[i-1]+1):W.index[i]] <- as.vector(W[[i]])
-    }
-    return(list(W=W.flat[1:W.index[m]], W.index=W.index, m=m))
-}
+## "W.flatten" <- function(W){
+##     m <- length(W)
+##     W.flat <- vector(mode="numeric", length=((m-1)*(m-1)*m))
+##     W.index <- vector(mode="numeric", length=m)
+##     W.index[1] <- dim(W[[1]])[1]*dim(W[[1]])[2]
+##     W.flat[1:W.index[1]] <- as.vector(W[[1]])
+##     for(i in 2:m){
+##       W.index[i] <- dim(W[[i]])[1]*dim(W[[i]])[2] + W.index[i-1]
+##       W.flat[(W.index[i-1]+1):W.index[i]] <- as.vector(W[[i]])
+##     }
+##     return(list(W=W.flat[1:W.index[m]], W.index=W.index, m=m))
+## }
 
-"Wlist.flatten" <- function(W){
-    N2 <- length(W)
-    m <- length(W[[1]])
-    W.flat <- vector(mode="numeric", length=((m-1)*(m-1)*m*N2))
-    W.index <- vector(mode="numeric", length=(m*N2))
-    agg.index <- 0
-    for(i in 1:N2){
-        for(j in 1:m){
-            dim.w <- dim(W[[i]][[j]])[1]
-            cur.index <- (((i-1)*m)+j)
-            if(i==1 && j==1){agg.index <- 0}else{agg.index <- W.index[(cur.index-1)]}
-            W.index[cur.index] <- ((dim.w*dim.w)+agg.index)
-            W.flat[(agg.index+1):W.index[cur.index]] <- as.vector(W[[i]][[j]])
-        }
-    }
-    return(list(W=W.flat[1:max(W.index)], W.index=W.index, m=m))
-}
+## "Wlist.flatten" <- function(W){
+##     N2 <- length(W)
+##     m <- length(W[[1]])
+##     W.flat <- vector(mode="numeric", length=((m-1)*(m-1)*m*N2))
+##     W.index <- vector(mode="numeric", length=(m*N2))
+##     agg.index <- 0
+##     for(i in 1:N2){
+##         for(j in 1:m){
+##             dim.w <- dim(W[[i]][[j]])[1]
+##             cur.index <- (((i-1)*m)+j)
+##             if(i==1 && j==1){agg.index <- 0}else{agg.index <- W.index[(cur.index-1)]}
+##             W.index[cur.index] <- ((dim.w*dim.w)+agg.index)
+##             W.flat[(agg.index+1):W.index[cur.index]] <- as.vector(W[[i]][[j]])
+##         }
+##     }
+##     return(list(W=W.flat[1:max(W.index)], W.index=W.index, m=m))
+## }
 
-"W.list" <- function(W){
-    m <- W$m
-    N2 <- length(W$W.index)/m
-    W.flat <- W$W
-    W.index <- W$W.index
-    rm(W)
-    W.list <- vector(mode="list",length=N2)
-    W.tmp <- vector(mode="list",length=m)
-    for(i in 1:N2){
-        for(j in 1:m){
-            if(i==1 && j==1){last.index <- 0}else{last.index <- W.index[(((i-1)*m)+(j-1))]}
-            cur.index <- W.index[(((i-1)*m)+j)]
-            dim.w <- sqrt(cur.index-last.index)
-            W.tmp[[j]] <- matrix(W.flat[(last.index+1):cur.index],nrow=dim.w)
-        }
-        W.list[[i]] <- W.tmp
-    }
-    return(W.list)
-}
+## "W.list" <- function(W){
+##     m <- W$m
+##     N2 <- length(W$W.index)/m
+##     W.flat <- W$W
+##     W.index <- W$W.index
+##     rm(W)
+##     W.list <- vector(mode="list",length=N2)
+##     W.tmp <- vector(mode="list",length=m)
+##     for(i in 1:N2){
+##         for(j in 1:m){
+##             if(i==1 && j==1){last.index <- 0}else{last.index <- W.index[(((i-1)*m)+(j-1))]}
+##             cur.index <- W.index[(((i-1)*m)+j)]
+##             dim.w <- sqrt(cur.index-last.index)
+##             W.tmp[[j]] <- matrix(W.flat[(last.index+1):cur.index],nrow=dim.w)
+##         }
+##         W.list[[i]] <- W.tmp
+##     }
+##     return(W.list)
+## }
 
 "W.get" <- function(W,index)
 {
@@ -333,128 +331,96 @@ function(capT,m,ncoef,num.exog,nu,H0,S0,Y,X,hstar1,Sh,u, Bh,Sh1)
 
 
 
-# ONE STEP Function to draw 1 A0 from the posterior of a structural
-# BVAR model.  Can be used for the over and just identified cases.
-# Inputs all come from setup function above or the model object.
+## # ONE STEP Function to draw 1 A0 from the posterior of a structural
+## # BVAR model.  Can be used for the over and just identified cases.
+## # Inputs all come from setup function above or the model object.
 
-# New version with memory conservation for A0's and W's
-"drawA0" <- function(A0gbs, UT, df, n0, Wout)
-  { # Set up constants and place holder matrices
-    m <- dim(A0gbs)[1]
+## # C++ version
+## "drawA0cpp" <- function(A0gbs, UT, df, n0, Wout){
+##     .Call("drawA0.cpp", A0gbs, UT, df, n0, Wout)
+## }
 
-    for(i in 1:m)
-      {
-        w <- matrix(0, m, 1)
+## # New version with memory conservation for A0's and W's
+## "drawA0" <- function(A0gbs, UT, df, n0, Wout)
+##   { # Set up constants and place holder matrices
+##     m <- dim(A0gbs)[1]
 
-        X <- A0gbs
-        X[,i] <- 0
-        tmp <- qr(t(X), tol=1e-12)  # replaces the LU call from above
+##     for(i in 1:m)
+##       {
+##         w <- matrix(0, m, 1)
+
+##         X <- A0gbs
+##         X[,i] <- 0
+##         tmp <- qr(t(X), tol=1e-12)  # replaces the LU call from above
 
 
-        # Now, get back the upper part of the decomposition for backsolving the
-        # system. We do not need the lower part
+##         # Now, get back the upper part of the decomposition for backsolving the
+##         # system. We do not need the lower part
 
-        U <- qr.R(tmp)  # gets the upper triangular part of the QR decomp
+##         U <- qr.R(tmp)  # gets the upper triangular part of the QR decomp
 
-        d.U <- abs(diag(U))            # find the singular values
-        sing.values <- d.U/max(d.U)
-        sing.index <- min(which(sing.values<2^-16)) # find the index of the
-                                                    # singular values for
-                                                    # the pivoted solution
+##         d.U <- abs(diag(U))            # find the singular values
+##         sing.values <- d.U/max(d.U)
+##         sing.index <- min(which(sing.values<2^-16)) # find the index of the
+##                                                     # singular values for
+##                                                     # the pivoted solution
 
-        jIx0 <- tmp$pivot[sing.index]  # need the location of the pivots / equations
+##         jIx0 <- tmp$pivot[sing.index]  # need the location of the pivots / equations
 
-        w[jIx0] <- 1
-        if(jIx0>1 && jIx0<(m+1))
-          {
-            jA <- U[1:(jIx0-1), 1:(jIx0-1)]
-            jb <- U[1:(jIx0-1), sing.index]  # this is the singular part,
-                                             # so it is at the end of the matrix
+##         w[jIx0] <- 1
+##         if(jIx0>1 && jIx0<(m+1))
+##           {
+##             jA <- U[1:(jIx0-1), 1:(jIx0-1)]
+##             jb <- U[1:(jIx0-1), sing.index]  # this is the singular part,
+##                                              # so it is at the end of the matrix
 
-            jy <- qr.solve(-jA, jb, tol=1e-12)
-            w[1:(jIx0-1)] <- jy
-          }
+##             jy <- qr.solve(-jA, jb, tol=1e-12)
+##             w[1:(jIx0-1)] <- jy
+##           }
 
-        # now find the orthonormal basis for the w_i... w_qi
-        w0 <- crossprod(UT[[i]], w)
-        w1 <- w0/sqrt(sum(w0^2))
+##         # now find the orthonormal basis for the w_i... w_qi
+##         w0 <- crossprod(UT[[i]], w)
+##         w1 <- w0/sqrt(sum(w0^2))
 
-     # This is a bit of a "cheat", but it lets us trap occurences
-     # where the solution is degenerate or the QR solution is fragile.  The
-     # w converge quickly (within the first 100 iterations, so reusing the
-     # previous ones in this error trap is probably OK.  If nothing
-     # else, it increases the numerical stability of the algorithm
+##      # This is a bit of a "cheat", but it lets us trap occurences
+##      # where the solution is degenerate or the QR solution is fragile.  The
+##      # w converge quickly (within the first 100 iterations, so reusing the
+##      # previous ones in this error trap is probably OK.  If nothing
+##      # else, it increases the numerical stability of the algorithm
 
-        # Check that we were able to get a new orthnormal basis.  If
-        # not, reuse the last one and find its QR
+##         # Check that we were able to get a new orthnormal basis.  If
+##         # not, reuse the last one and find its QR
 
-        if(is.na(sum(w1))==TRUE)
-        {
-            W <- Wout[[1]]
-            print("is.na(sum(w1))!")
-          } else {
-              W <- qr.Q(qr(w1, tol=1e-12), complete=T)
-          }
+##         if(is.na(sum(w1))==TRUE)
+##         {
+##             W <- Wout[[1]]
+##             print("is.na(sum(w1))!")
+##           } else {
+##               W <- qr.Q(qr(w1, tol=1e-12), complete=T)
+##           }
 
-        # Now trap that we got a valid QR.
-
-        if(is.numeric(W)==FALSE) {
-            print("Invalid qr.Q!")
-            W <- Wout[[i]]
-            print(W)
-        }
-
-        gkb <- matrix(0, n0[i], 1)
-        jstd <- sqrt(1/df)
-        if(n0[i]>1)
-          {
-            gkb[2:n0[i],1] <- jstd*rnorm(n0[i]-1)
-          }
-        jr <- jstd*rnorm(df+1)
-        gkb[1,1] <- ifelse(runif(1)<0.5, sqrt(crossprod(jr)),
-                           -1*sqrt(crossprod(jr)))
-        A0gbs[,i] <- UT[[i]]%*%(W%*%gkb)
-        Wout[[i]] <- W
-    }
-    return(list(A0gbs=A0gbs, W=Wout))
-}
-
-# list.print function --- used to recursively print the list objects
-# in the printing of the VAR objects for users.
-
-"list.print" <- function(x)
-{
-    if(is.list(x$values)){
-        cat("==========================================\n")
-        cat(x$labels[1],"\n")
-        cat("==========================================\n")
-        for(i in 1:length(x$values)) list.print(x$values[[i]])
-    } else {
-        if(length(dim(x$values))==3){
-            cat(x$labels[1],": \n",sep="")
-            for(j in 1:dim(x$values)[3]){
-                cat("B(", j, ")\n", sep="")
-                prmatrix(x$values[,,j])
-                cat("\n")
-            }
-        } else if(length(dim(x$values))==2) {
-            cat(x$labels[1],": \n",sep="")
-            prmatrix(x$values)
-        } else if(is.null(dim(x$values))){
-            if ((length(x$values)/length(x$labels))==1){
-                for(i in 1:length(x$values))
-                    cat(x$labels[i], ":    ", x$values[i], "\n")
-            } else {
-                cat(x$labels[1],":\n")
-                for(i in 1:length(x$values)) cat(x$values[i], "\t")
-                cat("\n")
-            }
-        }
-        cat("------------------------------------------\n")
-    }
-}
+##         # Now trap that we got a valid QR.
 
+##         if(is.numeric(W)==FALSE) {
+##             print("Invalid qr.Q!")
+##             W <- Wout[[i]]
+##             print(W)
+##         }
 
+##         gkb <- matrix(0, n0[i], 1)
+##         jstd <- sqrt(1/df)
+##         if(n0[i]>1)
+##           {
+##             gkb[2:n0[i],1] <- jstd*rnorm(n0[i]-1)
+##           }
+##         jr <- jstd*rnorm(df+1)
+##         gkb[1,1] <- ifelse(runif(1)<0.5, sqrt(crossprod(jr)),
+##                            -1*sqrt(crossprod(jr)))
+##         A0gbs[,i] <- UT[[i]]%*%(W%*%gkb)
+##         Wout[[i]] <- W
+##     }
+##     return(list(A0gbs=A0gbs, W=Wout))
+## }
 
 # old version, without memory conservation
 ## "drawA0" <- function(A0gbs, UT, df, n0, Wout)
